==> nomachine-8.9.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXShutdown.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXShutdown;no warnings;my (%__wasDisabled);sub handleShutdown{(my (
%parameters)=@_);if (defined ($parameters{"\x6d\x6f\x6e\x69\x74\x6f\x72"})){
Server::setClientConnectionClosed ();($parameters{"\x73\x69\x6c\x65\x6e\x63\x65"
}=(0x05b0+ 3232-0x124f));}if (((not (main::effectiveUserIsAdministrator ()))and 
(Common::NXCore::getEffectiveUsername ()eq "\x6e\x78"))){return (
shutdownForUserNx ());}Server::setServerIsShutdown ();setServiceStatuses ();
NXSystemDaemons::stop ("\x6e\x78\x64");main::nxrequire (
"\x4e\x58\x52\x65\x64\x69\x73\x53\x75\x62\x73\x63\x72\x69\x70\x74\x69\x6f\x6e");
NXRedisSubscription::publishToSubscribers (($GLOBAL::MSG_SHUTDOWN_TERMINATE.
"\x20\x53\x68\x75\x74\x64\x6f\x77\x6e\x20\x74\x65\x72\x6d\x69\x6e\x61\x74\x65\x20\x72\x65\x71\x75\x65\x73\x74\x20\x72\x65\x61\x73\x6f\x6e\x3d\x73\x68\x75\x74\x64\x6f\x77\x6e\x20"
));NXSystemDaemons::setShutdownFlag ();main::nxrequire (
"\x53\x65\x72\x76\x69\x63\x65");(my $error=Service::setStopFlag ());if (((not (
defined ($parameters{"\x73\x69\x6c\x65\x6e\x63\x65"})))or ($parameters{
"\x73\x69\x6c\x65\x6e\x63\x65"}eq (0x06c7+ 5806-0x1d75)))){if (($error==
(0x0a75+ 5155-0x1e98))){if (serviceWasDisabled (
"\x6e\x78\x73\x65\x72\x76\x65\x72")){NXMsg::info (
"\x69\x53\x65\x72\x76\x69\x63\x65\x41\x6c\x72\x65\x61\x64\x79\x44\x69\x73\x61\x62\x6c\x65\x64"
,"\x4e\x58\x53\x79\x73\x74\x65\x6d\x44\x61\x65\x6d\x6f\x6e\x73",
"\x6e\x78\x73\x65\x72\x76\x65\x72");}else{NXMsg::info (
"\x69\x53\x65\x72\x76\x69\x63\x65\x44\x69\x73\x61\x62\x6c\x65\x64",
"\x4e\x58\x53\x79\x73\x74\x65\x6d\x44\x61\x65\x6d\x6f\x6e\x73",
"\x6e\x78\x73\x65\x72\x76\x65\x72");}}else{(my $errorString=
libnxh::NXGetErrorString ());Common::NXMsg::error (
"\x65\x47\x55\x49\x43\x61\x6e\x6e\x6f\x74\x43\x72\x65\x61\x74\x65\x46\x69\x6c\x65"
,$GLOBAL::ServerStopStatusFlagLink,$errorString);NXMsg::error (
"\x65\x43\x61\x6e\x6e\x6f\x74\x53\x74\x6f\x70\x53\x65\x72\x76\x69\x63\x65",
"\x4e\x58\x53\x79\x73\x74\x65\x6d\x44\x61\x65\x6d\x6f\x6e\x73",
"\x6e\x78\x73\x65\x72\x76\x65\x72");}}main::setSSHStatusShutdown ();
main::nxrequire ("\x4e\x58\x46\x69\x72\x65\x77\x61\x6c\x6c");
NXFirewall::delFirewallRules ();NXSystemDaemons::stop (
"\x6e\x78\x73\x65\x72\x76\x65\x72");NXSystemDaemons::printStatus (
"\x6e\x78\x6e\x6f\x64\x65");if (NXSystemDaemons::isServiceEnabled (
"\x6e\x78\x68\x74\x64")){NXSystemDaemons::stop ("\x6e\x78\x68\x74\x64");}
NXUpdate::killUpdate ();NXTerminate::terminateAll ((0x0852+ 5651-0x1e64));
main::nxrequire ("\x4e\x58\x43\x6c\x75\x73\x74\x65\x72");if (
NXCluster::isEnabled ()){NXCluster::standby ();}main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");
NXScripts::handleLeftoverSystemLoadScriptCleanup ();__resetWasDisabled ();return
 ((0x1f05+ 372-0x2079));}sub setServiceStatuses{(my $servicesToCheck=
"\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x6e\x78\x6e\x6f\x64\x65\x20\x6e\x78\x64");
if (NXLicense::isHttpdSupportFeature ()){($servicesToCheck.=
"\x20\x6e\x78\x68\x74\x64");}($response=
NXSystemDaemons::askServerDaemonForServiceStatus ($servicesToCheck));if (defined
 ($response)){(my (@services)=split ( /, / ,$response,(0x17ad+ 1442-0x1d4f)));
foreach my $service (@services){if (($service=~ /(.*) Disabled/ )){(
$__wasDisabled{$1}=(0x03bb+  71-0x0401));}}}else{($__wasDisabled{
"\x6e\x78\x6e\x6f\x64\x65"}=(0x0f99+ 2906-0x1af2));(my (@services)=(
"\x6e\x78\x73\x65\x72\x76\x65\x72","\x6e\x78\x64"));if (
NXLicense::isHttpdSupportFeature ()){push (@services,"\x6e\x78\x68\x74\x64");}
foreach my $serviceName (@services){if ((not (NXSystemDaemons::isRunning (
$serviceName)))){($__wasDisabled{$serviceName}=(0x1a74+ 1695-0x2112));}}}}sub 
serviceWasDisabled{(my $service=shift (@_));if ((defined ($__wasDisabled{
$service})and ($__wasDisabled{$service}==(0x0d87+ 5386-0x2290)))){return (
(0x083f+ 3958-0x17b4));}return ((0x1377+ 1946-0x1b11));}sub __resetWasDisabled{(my (
@services)=("\x6e\x78\x73\x65\x72\x76\x65\x72","\x6e\x78\x64",
"\x6e\x78\x6e\x6f\x64\x65"));if (NXLicense::isHttpdSupportFeature ()){push (
@services,"\x6e\x78\x68\x74\x64");}foreach my $serviceName (@services){(
$__wasDisabled{$serviceName}=undef);}}sub shutdownForUserNx{Logger::debug (
"\x53\x68\x75\x74\x64\x6f\x77\x6e\x20\x66\x6f\x72\x20\x75\x73\x65\x72\x20\x6e\x78\x2e"
);(my (@command)=());push (@command,$GLOBAL::CommandNXexec,
"\x6e\x78\x73\x68\x75\x74\x64\x6f\x77\x6e\x2e\x73\x68");(my (@parameters)=());
main::run_command ((\@command),(\@parameters));return ((0x00f0+ 4309-0x11c5));}
return ((0x033d+ 2928-0x0eac));

==> nomachine-8.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXShutdown.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXShutdown;no warnings;my (%__wasDisabled);sub handleShutdown{(my (
%parameters)=@_);if (defined ($parameters{"\x6d\x6f\x6e\x69\x74\x6f\x72"})){
Server::setClientConnectionClosed ();($parameters{"\x73\x69\x6c\x65\x6e\x63\x65"
}=(0x15cb+ 2477-0x1f77));}if (((not (main::effectiveUserIsAdministrator ()))and 
(Common::NXCore::getEffectiveUsername ()eq "\x6e\x78"))){return (
shutdownForUserNx ());}Server::setServerIsShutdown ();setServiceStatuses ();
NXSystemDaemons::stop ("\x6e\x78\x64");main::nxrequire (
"\x4e\x58\x52\x65\x64\x69\x73\x53\x75\x62\x73\x63\x72\x69\x70\x74\x69\x6f\x6e");
NXRedisSubscription::publishToSubscribers (($GLOBAL::MSG_SHUTDOWN_TERMINATE.
"\x20\x53\x68\x75\x74\x64\x6f\x77\x6e\x20\x74\x65\x72\x6d\x69\x6e\x61\x74\x65\x20\x72\x65\x71\x75\x65\x73\x74\x20\x72\x65\x61\x73\x6f\x6e\x3d\x73\x68\x75\x74\x64\x6f\x77\x6e\x20"
));NXSystemDaemons::setShutdownFlag ();main::nxrequire (
"\x53\x65\x72\x76\x69\x63\x65");(my $error=Service::setStopFlag ());if (((not (
defined ($parameters{"\x73\x69\x6c\x65\x6e\x63\x65"})))or ($parameters{
"\x73\x69\x6c\x65\x6e\x63\x65"}eq (0x0084+ 5868-0x1770)))){if (($error==
(0x1a02+ 1296-0x1f12))){if (serviceWasDisabled (
"\x6e\x78\x73\x65\x72\x76\x65\x72")){NXMsg::info (
"\x69\x53\x65\x72\x76\x69\x63\x65\x41\x6c\x72\x65\x61\x64\x79\x44\x69\x73\x61\x62\x6c\x65\x64"
,"\x4e\x58\x53\x79\x73\x74\x65\x6d\x44\x61\x65\x6d\x6f\x6e\x73",
"\x6e\x78\x73\x65\x72\x76\x65\x72");}else{NXMsg::info (
"\x69\x53\x65\x72\x76\x69\x63\x65\x44\x69\x73\x61\x62\x6c\x65\x64",
"\x4e\x58\x53\x79\x73\x74\x65\x6d\x44\x61\x65\x6d\x6f\x6e\x73",
"\x6e\x78\x73\x65\x72\x76\x65\x72");}}else{(my $errorString=
libnxh::NXGetErrorString ());Common::NXMsg::error (
"\x65\x47\x55\x49\x43\x61\x6e\x6e\x6f\x74\x43\x72\x65\x61\x74\x65\x46\x69\x6c\x65"
,$GLOBAL::ServerStopStatusFlagLink,$errorString);NXMsg::error (
"\x65\x43\x61\x6e\x6e\x6f\x74\x53\x74\x6f\x70\x53\x65\x72\x76\x69\x63\x65",
"\x4e\x58\x53\x79\x73\x74\x65\x6d\x44\x61\x65\x6d\x6f\x6e\x73",
"\x6e\x78\x73\x65\x72\x76\x65\x72");}}main::setSSHStatusShutdown ();
main::nxrequire ("\x4e\x58\x46\x69\x72\x65\x77\x61\x6c\x6c");
NXFirewall::delFirewallRules ();NXSystemDaemons::stop (
"\x6e\x78\x73\x65\x72\x76\x65\x72");NXSystemDaemons::printStatus (
"\x6e\x78\x6e\x6f\x64\x65");if (NXSystemDaemons::isServiceEnabled (
"\x6e\x78\x68\x74\x64")){NXSystemDaemons::stop ("\x6e\x78\x68\x74\x64");}
NXUpdate::killUpdate ();NXTerminate::terminateAll ((0x11f5+ 2001-0x19c5));
main::nxrequire ("\x4e\x58\x43\x6c\x75\x73\x74\x65\x72");if (
NXCluster::isEnabled ()){NXCluster::standby ();}main::nxrequire (
"\x4e\x58\x53\x63\x72\x69\x70\x74\x73");
NXScripts::handleLeftoverSystemLoadScriptCleanup ();__resetWasDisabled ();return
 ((0x008b+ 5996-0x17f7));}sub setServiceStatuses{(my $servicesToCheck=
"\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x6e\x78\x6e\x6f\x64\x65\x20\x6e\x78\x64");
if (NXLicense::isHttpdSupportFeature ()){($servicesToCheck.=
"\x20\x6e\x78\x68\x74\x64");}($response=
NXSystemDaemons::askServerDaemonForServiceStatus ($servicesToCheck));if (defined
 ($response)){(my (@services)=split ( /, / ,$response,(0x048d+ 3823-0x137c)));
foreach my $service (@services){if (($service=~ /(.*) Disabled/ )){(
$__wasDisabled{$1}=(0x00f7+ 8478-0x2214));}}}else{($__wasDisabled{
"\x6e\x78\x6e\x6f\x64\x65"}=(0x0174+ 9429-0x2648));(my (@services)=(
"\x6e\x78\x73\x65\x72\x76\x65\x72","\x6e\x78\x64"));if (
NXLicense::isHttpdSupportFeature ()){push (@services,"\x6e\x78\x68\x74\x64");}
foreach my $serviceName (@services){if ((not (NXSystemDaemons::isRunning (
$serviceName)))){($__wasDisabled{$serviceName}=(0x077a+ 5782-0x1e0f));}}}}sub 
serviceWasDisabled{(my $service=shift (@_));if ((defined ($__wasDisabled{
$service})and ($__wasDisabled{$service}==(0x03a0+ 8064-0x231f)))){return (
(0x0204+ 216-0x02db));}return ((0x08d3+ 7475-0x2606));}sub __resetWasDisabled{(my (
@services)=("\x6e\x78\x73\x65\x72\x76\x65\x72","\x6e\x78\x64",
"\x6e\x78\x6e\x6f\x64\x65"));if (NXLicense::isHttpdSupportFeature ()){push (
@services,"\x6e\x78\x68\x74\x64");}foreach my $serviceName (@services){(
$__wasDisabled{$serviceName}=undef);}}sub shutdownForUserNx{Logger::debug (
"\x53\x68\x75\x74\x64\x6f\x77\x6e\x20\x66\x6f\x72\x20\x75\x73\x65\x72\x20\x6e\x78\x2e"
);(my (@command)=());push (@command,$GLOBAL::CommandNXexec,
"\x6e\x78\x73\x68\x75\x74\x64\x6f\x77\x6e\x2e\x73\x68");(my (@parameters)=());
main::run_command ((\@command),(\@parameters));return ((0x0c9b+ 297-0x0dc4));}
return ((0x0010+ 9668-0x25d3));
